@@ -23,3 +23,8 @@ set_resource_for_product = client.set_resource_for_product
 get_resource_for_product = client.get_resource_for_product
 execute_post = client.execute_post
 execute_get = client.execute_get
+experiment = client.experiment
+experiment_download = client.experiment_download
+experiment_upload = client.experiment_upload
+experiment_get_result = client.experiment_get_result
+get_error_messages = client.get_error_messages
