@@ -6,7 +6,7 @@ from strangeworks.core.config.base import ConfigSource
 from strangeworks.core.config.defaults import DefaultConfig
 from strangeworks.core.config.env import EnvConfig
 from strangeworks.core.config.file import ConfigFile
-from strangeworks.core.utils import is_empty_str
+from strangeworks.core.utils import fix_str_attr, is_empty_str
 
 DEFAULT_CFG_FILE_PATH = "~/.config/strangeworks/sdk/cfg.toml"
 DEFAULT_PROFILE_NAME = "default"
@@ -30,9 +30,9 @@ class Config(ConfigSource):
         User can specify a custom path for a configuration file by setting the
         STRANGEWORKS_CONFIG_PATH environment variable.
         """
+        super().__init__(**kwargs)
         self._cfg_sources = {"env": EnvConfig(), "default": DefaultConfig()}
         self._init_cfg_file()
-        super().__init__(**kwargs)
 
     def _init_cfg_file(self) -> Optional[ConfigFile]:
         try:
@@ -43,7 +43,7 @@ class Config(ConfigSource):
             )
             # config file may have an active profile set. if it is,
             # retrieve it and set it for everyone.
-            _active_profile_from_file = file.get_active_profile_from_file()
+            _active_profile_from_file = file.get_active_profile()
             if _active_profile_from_file:
                 self.set_active_profile(_active_profile_from_file)
             self._cfg_sources["file"] = file
@@ -56,14 +56,27 @@ class Config(ConfigSource):
 
         Checks sources in the order specified by _CFG_SOURCE_ORDER for requested item
         and returns as soon as a value is found.
+
+        Parameters
+        ----------
+        key: str
+            Name of the configuration variable
+        profile: Optional[str]
+            Name of the profile to use to retrieve value. Overrides active profile.
+
+        Returns
+        -------
+        Optional[str]
+            A string value corresponding to the key or None.
         """
         if "file" not in self._cfg_sources:
             self._init_cfg_file()
 
-        _prof = self._fix_profile(profile)
+        # override active profile if caller provided one
+        _profile = self._fix_profile(profile)
         for src_type in Config._CFG_SOURCE_ORDER:
             if src_type in self._cfg_sources:
-                v = self._cfg_sources[src_type].get(key, _prof)
+                v = self._cfg_sources[src_type].get(key, _profile)
                 if v:
                     return v
         return None
@@ -71,9 +84,13 @@ class Config(ConfigSource):
     def set(self, profile: Optional[str] = None, overwrite: bool = False, **params):
         """Set configuration variables.
 
-        If a file configuration is missing, it will create one.
+        If a file configuration is missing, it will create one. Note that this method
+        will not update the current active_profile to the profile provided for this
+        call. In order to switch the active_profile, the set_active_profile method
+        must be called explicitly.
         """
         fixed_profile = self._fix_profile(profile)
+
         for _, cfg in self._cfg_sources.items():
             cfg.set_active_profile(self.get_active_profile())
             cfg.set(profile=fixed_profile, overwrite=overwrite, **params)
@@ -93,10 +110,46 @@ class Config(ConfigSource):
             )
             self._cfg_sources["file"] = cfg_file
 
+    def set_active_profile(self, active_profile: str):
+        """Update active profile.
+
+        Update active profile for self and all ConfigSource objects contained in
+        this object.That active profile for ConfigSource objects contained in this
+        object will be updated only if its different than its current value.
+
+        Parameters
+        ----------
+        active_profile: str
+            The profile to use as default profile.
+
+        Returns
+        -------
+        None
+        """
+        super().set_active_profile(active_profile)
+        for _, cfg in self._cfg_sources.items():
+            if cfg.get_active_profile() != self.get_active_profile():
+                cfg.set_active_profile(self.get_active_profile())
+
     def _fix_profile(self, profile: Optional[str] = None) -> str:
-        """Return default profile name if given profile is an empty string."""
+        """Return fixed profile.
+
+        Converts given profile value by removing leading and trailing spaces and
+        converting it to lowercase.
+        Returns active profile if none or empty string was passed in.
+
+        Parameters
+        ----------
+        profile: Optional[str] = None
+            Name of the profile. Defaults to None
+
+        Returns
+        -------
+        :str
+            profile name adjusted as described above.
+        """
         return (
             self.get_active_profile()
             if is_empty_str(profile)
-            else profile.strip().lower()
+            else fix_str_attr(profile)
         )
