@@ -2,7 +2,7 @@
 import os
 from typing import Optional
 
-from strangeworks.core.config.base import ConfigSource
+from strangeworks.core.config.base import DEFAULT_PROFILE_NAME, ConfigSource
 from strangeworks.core.utils import is_empty_str
 
 
@@ -15,7 +15,7 @@ class EnvConfig(ConfigSource):
     letters.
     """
 
-    def get(self, key: str, profile: str = "default") -> Optional[str]:
+    def get(self, key: str, profile: str = DEFAULT_PROFILE_NAME) -> Optional[str]:
         """Retrieve the values from environment variables.
 
         The method will convert all lowercase key or profile values to uppercase.
@@ -26,7 +26,9 @@ class EnvConfig(ConfigSource):
         env_var = EnvConfig._get_envvar_name(key=key, profile=profile)
         return os.getenv(env_var)
 
-    def set(self, profile: str = "default", overwrite: bool = False, **params):
+    def set(
+        self, profile: str = DEFAULT_PROFILE_NAME, overwrite: bool = False, **params
+    ):
         """Set method for environment variables.
 
         Existing environment variables will be updated only if overwrite is set
@@ -34,10 +36,10 @@ class EnvConfig(ConfigSource):
         """
         for key, val in params.items():
             envvar_name = EnvConfig._get_envvar_name(key=key, profile=profile)
-            # overwrite existing envvars iff overwrite is set to True.
-            if envvar_name in os.environ and overwrite:
+            # overwrite existing envvars only if overwrite is True.
+            if envvar_name not in os.environ or overwrite:
                 os.environ[envvar_name] = val
 
     @staticmethod
-    def _get_envvar_name(key: str, profile: str = "default"):
+    def _get_envvar_name(key: str, profile: str = DEFAULT_PROFILE_NAME):
         return f"STRANGEWORKS_CONFIG_{profile.upper()}_{key.upper()}"
