@@ -5,9 +5,9 @@ from typing import Optional
 import tomlkit
 from tomlkit.exceptions import NonExistentKey
 
-from strangeworks.core.config.base import ConfigSource
+from strangeworks.core.config.base import DEFAULT_PROFILE_NAME, ConfigSource
 from strangeworks.core.errors.error import StrangeworksError
-from strangeworks.core.utils import is_empty_str
+from strangeworks.core.utils import fix_str_attr, is_empty_str
 
 DEFAULT_CFG_FILE_PATH = "~/.config/strangeworks/sdk/cfg.toml"
 
@@ -54,14 +54,17 @@ class ConfigFile(ConfigSource):
             )
 
         self._file_path = os.path.expanduser(file_path)
-        self._load()
+        # call base class init first, then set the active_profile in _load method.
         super().__init__()
+        self._load()
 
     def _load(self):
         """Load configuration from file."""
         with open(self._file_path, "rb") as f:
             self._cfg = tomlkit.load(f)
             self._stat = os.stat(self._file_path)
+            active_profile = self._cfg.get("active_profile") or DEFAULT_PROFILE_NAME
+            self.set_active_profile(active_profile)
             f.close()
 
     def _reload(self):
@@ -74,13 +77,13 @@ class ConfigFile(ConfigSource):
             # file has been removed since startup...go with what we have
             pass
 
-    def get(self, key: str, profile: str = "default") -> Optional[str]:
+    def get(self, key: str, profile: Optional[str] = None) -> Optional[str]:
         """
         Retrieve value of given key.
 
-        If the source configuration file has a modification timestamp that is more
-        recent than when configuration was read in, configuration will be reloaded
-        from the file before it is retrieved.
+        If the source configuration file has a modification timestamp that is
+        more recent than when configuration was read in, configuration will be
+        reloaded from the file before it is retrieved.
 
         Parameters
         ----------
@@ -94,11 +97,11 @@ class ConfigFile(ConfigSource):
         Value of the requested configuration or None
         """
         self._reload()
-        if is_empty_str(key) or is_empty_str(profile):
+        _profile = fix_str_attr(profile) or self.get_active_profile()
+        if is_empty_str(key) or is_empty_str(_profile):
             return None
 
-        _profile = ConfigFile._fix(profile)
-        _key = ConfigFile._fix(key)
+        _key = fix_str_attr(key)
         try:
             p = self._cfg.item(_profile)
             val = p[_key]
@@ -106,7 +109,12 @@ class ConfigFile(ConfigSource):
         except NonExistentKey:
             return None
 
-    def set(self, profile: str, overwrite: bool = False, **params):
+    def set(
+        self,
+        profile: str,
+        overwrite: bool = False,
+        **params,
+    ):
         """Set configuration values and save to file.
 
         If a key already exists, its value will be overwritten only if `overwrite` is
@@ -115,7 +123,8 @@ class ConfigFile(ConfigSource):
         Parameters
         ----------
         profile: str
-            Name of the profile to use for the value. Cannot be an empty string or None
+            Name of the profile to use for the setting values. Must be a non-empty
+            string.
         overwrite: bool
             Indicates whether a value that already exists should be overwritten
         **params:
@@ -126,23 +135,16 @@ class ConfigFile(ConfigSource):
                 "Profile name cannot be an empty string or None."
             )
         self._reload()
-        _profile = ConfigFile._fix(profile)
-        if profile not in self._cfg:
+        _profile = fix_str_attr(profile)
+        if _profile not in self._cfg:
             self._cfg[_profile] = tomlkit.table()
         for key, val in params.items():
-            _key = ConfigFile._fix(key)
+            _key = fix_str_attr(key)
             if _key not in self._cfg[_profile] or overwrite:
                 self._cfg[_profile][_key] = val
         self._cfg["active_profile"] = self.get_active_profile()
         ConfigFile._write_file(self._cfg.as_string(), self._file_path)
 
-    def get_active_profile_from_file(self) -> Optional[str]:
-        return self._cfg.get("active_profile") if self._cfg else None
-
-    @staticmethod
-    def _fix(s: str) -> str:
-        return s.strip().lower()
-
     @staticmethod
     def create_file(
         profile: str,
@@ -167,13 +169,13 @@ class ConfigFile(ConfigSource):
             )
 
         fpath = os.path.expanduser(file_path)
-        _profile = ConfigFile._fix(profile)
+        _profile = fix_str_attr(profile)
         doc = tomlkit.document()
         doc.add("title", "Strangeworks SDK configuration settings.")
-        doc.add("active_profile", active_profile or "default")
+        doc.add("active_profile", active_profile or DEFAULT_PROFILE_NAME)
         t = tomlkit.table()
         for key, value in params.items():
-            _key = ConfigFile._fix(key)
+            _key = fix_str_attr(key)
             t.add(_key, value)
         doc.add(_profile, t)
 
